==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridSortDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSortDescriptionsChangedEventArgsDescription } from "./GridSortDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSortDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSortDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridSortDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSortDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.c(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("SortDescriptions", "Collection:ColumnSortDescription:ColumnSortDescriptionCollection:ColumnSortDescription");
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSortDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSortDescriptionsChangedEventArgs", function () { return new GridSortDescriptionsChangedEventArgsDescription(); });
        a.z("GridSortDescriptionsChangedEventArgs", GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridSortDescriptionsChangedEventArgsDescriptionMetadata, 'GridSortDescriptionsChangedEventArgsDescriptionMetadata');
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSortDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSortDescriptionsChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridSortDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSortDescriptionsChangedEventArgsDescription } from "./GridSortDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSortDescriptionsChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSortDescriptionsChangedEventArgsDescriptionMetadata, _super);
    function GridSortDescriptionsChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSortDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSortDescriptionsChangedEventArgsDescriptionMetadata.c(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("SortDescriptions", "Collection:ColumnSortDescription:ColumnSortDescriptionCollection:ColumnSortDescription");
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSortDescriptionsChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridSortDescriptionsChangedEventArgs", function () { return new GridSortDescriptionsChangedEventArgsDescription(); });
        a.ab("GridSortDescriptionsChangedEventArgs", GridSortDescriptionsChangedEventArgsDescriptionMetadata.a);
    };
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.$t = markType(GridSortDescriptionsChangedEventArgsDescriptionMetadata, 'GridSortDescriptionsChangedEventArgsDescriptionMetadata');
    GridSortDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridSortDescriptionsChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSortDescriptionsChangedEventArgsDescriptionMetadata };
